@@ -186,6 +186,64 @@ void UnlabeledParseModel::SaveFeatureVectors(
 }
 
 
+void UnlabeledParseModel::PrintArcScores(
+    std::ostream &out, const Sentence &sentence) const {
+  // (ROOTޤ)ʸñ = դΥΡɿ
+  const size_t N = sentence.rows.size();
+  // å
+  std::vector<std::vector<double> > score(N, std::vector<double>(N, -1.0));
+
+  // iܤȯ륨åΥȤ׻
+  // MSTǤϷθȥդθդˤʤ뤳Ȥ
+  // ROOTϽȯʤΤǡi = 0 ϥå
+  for (size_t i = 1; i < N; i++) {
+    const size_t begin = left_to_right_ ? i + 1 : 0;
+    double sum = 0;
+    for (size_t j = begin; j < N; j++) {
+      if (j != i) {
+        std::string feature_string;
+        extractor_->Extract(sentence, i, j, &feature_string);
+
+        std::stringstream ss(feature_string);
+        FeatureVector feature_vector;
+        std::string feature;
+        while (ss >> feature) {
+          FeatureID fid = feature_indexer_.GetID(feature);
+          if (fid != kInvalidFeatureID) {
+            feature_vector.push_back( Feature(fid, 1.0) );
+          }
+        }
+        // Ȥϵոͤ򥻥å
+        score[j][i] = exp(feature_vector.Product(weight_));
+        sum += score[j][i];
+      }
+    }
+    // 
+    for (size_t j = begin; j < N; j++) {
+      if (j != i) { score[j][i] /= sum; }
+    }
+  }
+
+
+  // print legend
+  out << "src\\dst";
+  for (size_t i = 0; i < N; i++) {
+    out << "\t" << sentence.rows[i].form;
+  }
+  out << std::endl;
+
+  for (size_t src = 0; src < N; src++) {
+    out << sentence.rows[src].form;
+    for (size_t dst = 0; dst < N; dst++) {
+      out << "\t" << score[dst][src];
+    }
+    out << std::endl;
+  }
+  out << std::endl;
+
+  return;
+}
+
 void UnlabeledParseModel::ParseSentenceWithMST(
     const bool &named_entity_p, Sentence *sentence) const {
   // (ROOTޤ)ʸñ = դΥΡɿ
@@ -219,7 +277,9 @@ void UnlabeledParseModel::ParseSentenceWithMST(
       }
     }
     // 
-    for (size_t j = begin; j < N; j++) { score[j][i] /= sum; }
+    for (size_t j = begin; j < N; j++) {
+      if (j != i) { score[j][i] /= sum; }
+    }
   }
 
 
